@@ -624,7 +624,7 @@ func TestFormat(t *testing.T) {
 		if len(tc.expected) < 1000 {
 			name = tc.expected + "/" + tc.format
 		} else {
-			name = strings.Replace(tc.expected+"/"+tc.format, strings.Repeat("0", 30), "0.", -1)
+			name = strings.ReplaceAll(tc.expected+"/"+tc.format, strings.Repeat("0", 30), "0.")
 		}
 		t.Run(name, func(t *testing.T) {
 			got := timefmt.Format(tc.t, tc.format)
@@ -649,3 +649,13 @@ func ExampleFormat() {
 	fmt.Println(str)
 	// Output: 2020-07-24 09:07:29
 }
+
+func ExampleAppendFormat() {
+	t := time.Date(2020, time.July, 24, 9, 7, 29, 0, time.UTC)
+	buf := make([]byte, 0, 64)
+	buf = append(buf, '(')
+	buf = timefmt.AppendFormat(buf, t, "%Y-%m-%d %H:%M:%S")
+	buf = append(buf, ')')
+	fmt.Println(string(buf))
+	// Output: (2020-07-24 09:07:29)
+}
