@@ -445,7 +445,7 @@ var parseTestCases = []struct {
 	{
 		source: "2020-07-24 23:14:15 +0000",
 		format: "%F %T %z",
-		t:      time.Date(2020, time.July, 24, 23, 14, 15, 0, time.UTC),
+		t:      time.Date(2020, time.July, 24, 23, 14, 15, 0, time.FixedZone("", 0)),
 	},
 	{
 		source: "2020-07-24T23:14:15Z",
@@ -702,6 +702,16 @@ var parseTestCases = []struct {
 		format:   "%Z",
 		parseErr: errors.New(`cannot parse "X" with "%Z"`),
 	},
+	{
+		source: "2020-07-24 23:14:15 +0530 (AAA)",
+		format: "%F %T %z (%Z)",
+		t:      time.Date(2020, time.July, 24, 23, 14, 15, 0, time.FixedZone("AAA", (5*60+30)*60)),
+	},
+	{
+		source: "2020-07-24 23:14:15 (AAA) +0530",
+		format: "%F %T (%Z) %z",
+		t:      time.Date(2020, time.July, 24, 23, 14, 15, 0, time.FixedZone("AAA", (5*60+30)*60)),
+	},
 	{
 		source: "01%02\t03\n450000",
 		format: "%H%%%M%t%S%n%f",
@@ -743,6 +753,14 @@ func TestParse(t *testing.T) {
 				if !got.Equal(tc.t) {
 					t.Errorf("expected: %v, got: %v", tc.t, got)
 				}
+				name, offset := tc.t.Zone()
+				gotName, gotOffset := got.Zone()
+				if name != gotName || offset != gotOffset {
+					t.Errorf("expected zone: name = %s, offset = %d, got zone: name = %s, offset = %d",
+						name, offset,
+						gotName, gotOffset,
+					)
+				}
 			} else {
 				if err == nil {
 					t.Fatalf("expected error %v but got: %v", tc.parseErr, err)
